==> 0.0.2.tar.gz: android/src/main/java/com/yifan/yf_ads/bean/DrawFeedVideoBean.java <==
package com.yifan.yf_ads.bean;

import org.json.JSONException;
import org.json.JSONObject;

public class DrawFeedVideoBean {
    //自定义1：设置广告视频区域是否响应点击行为，控制视频暂停、继续播放，默认不响应；
    boolean interruptVideoPlay;
    String pauseIconPath;
    int pauseIconResource;
    int pauseIconSize;
    int drawFeedItemLayoutId;
    int drawFeedPageLayoutId;
    int gravity;
    int topMargin;
    int bottomMargin;
    int leftMargin;
    int rightMargin;

    int width;
    int height;
    String positionId;
    int uniqueKey;
    boolean cache;

    public static DrawFeedVideoBean parseObject(String jsonString) throws JSONException {
        DrawFeedVideoBean bean = new DrawFeedVideoBean();
        JSONObject jsonObject = new JSONObject(jsonString);
        bean.positionId = jsonObject.optString("positionId");
        bean.width = jsonObject.optInt("width");
        bean.height = jsonObject.optInt("height");
        bean.uniqueKey = jsonObject.optInt("uniqueKey");
        bean.cache = jsonObject.optBoolean("cache");

        bean.interruptVideoPlay = jsonObject.optBoolean("interruptVideoPlay");
        bean.pauseIconPath = jsonObject.optString("pauseIconPath");
        bean.pauseIconResource = jsonObject.optInt("pauseIconResource");
        bean.pauseIconSize = jsonObject.optInt("pauseIconSize");
        bean.drawFeedItemLayoutId = jsonObject.optInt("drawFeedItemLayoutId");
        bean.drawFeedPageLayoutId = jsonObject.optInt("drawFeedPageLayoutId");
        bean.gravity = jsonObject.optInt("gravity");
        bean.topMargin = jsonObject.optInt("topMargin");
        bean.bottomMargin = jsonObject.optInt("bottomMargin");
        bean.leftMargin = jsonObject.optInt("leftMargin");
        bean.rightMargin = jsonObject.optInt("rightMargin");
        return bean;
    }


    public boolean isInterruptVideoPlay() {
        return interruptVideoPlay;
    }

    public void setInterruptVideoPlay(boolean interruptVideoPlay) {
        this.interruptVideoPlay = interruptVideoPlay;
    }

    public String getPauseIconPath() {
        return pauseIconPath;
    }

    public void setPauseIconPath(String pauseIconPath) {
        this.pauseIconPath = pauseIconPath;
    }

    public int getPauseIconResource() {
        return pauseIconResource;
    }

    public void setPauseIconResource(int pauseIconResource) {
        this.pauseIconResource = pauseIconResource;
    }

    public int getDrawFeedItemLayoutId() {
        return drawFeedItemLayoutId;
    }

    public void setDrawFeedItemLayoutId(int drawFeedItemLayoutId) {
        this.drawFeedItemLayoutId = drawFeedItemLayoutId;
    }

    public int getDrawFeedPageLayoutId() {
        return drawFeedPageLayoutId;
    }

    public void setDrawFeedPageLayoutId(int drawFeedPageLayoutId) {
        this.drawFeedPageLayoutId = drawFeedPageLayoutId;
    }

    public int getGravity() {
        return gravity;
    }

    public void setGravity(int gravity) {
        this.gravity = gravity;
    }

    public int getTopMargin() {
        return topMargin;
    }

    public void setTopMargin(int topMargin) {
        this.topMargin = topMargin;
    }

    public int getBottomMargin() {
        return bottomMargin;
    }

    public void setBottomMargin(int bottomMargin) {
        this.bottomMargin = bottomMargin;
    }

    public int getLeftMargin() {
        return leftMargin;
    }

    public void setLeftMargin(int leftMargin) {
        this.leftMargin = leftMargin;
    }

    public int getRightMargin() {
        return rightMargin;
    }

    public void setRightMargin(int rightMargin) {
        this.rightMargin = rightMargin;
    }

    public int getPauseIconSize() {
        return pauseIconSize;
    }

    public void setPauseIconSize(int pauseIconSize) {
        this.pauseIconSize = pauseIconSize;
    }

    public int getWidth() {
        return width;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getHeight() {
        return height;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public int getUniqueKey() {
        return uniqueKey;
    }

    public void setUniqueKey(int uniqueKey) {
        this.uniqueKey = uniqueKey;
    }

    public boolean isCache() {
        return cache;
    }

    public void setCache(boolean cache) {
        this.cache = cache;
    }
}

==> 0.0.9.tar.gz: android/src/main/java/com/yifan/yf_ads/bean/DrawFeedVideoBean.java <==
package com.yifan.yf_ads.bean;

import org.json.JSONException;
import org.json.JSONObject;

public class DrawFeedVideoBean {
    //自定义1：设置广告视频区域是否响应点击行为，控制视频暂停、继续播放，默认不响应；
    boolean interruptVideoPlay;
    String pauseIconPath;
    int pauseIconResource;
    int pauseIconSize;
    int drawFeedItemLayoutId;
    int drawFeedPageLayoutId;
    int gravity;
    int topMargin;
    int bottomMargin;
    int leftMargin;
    int rightMargin;

    int width;
    int height;
    String positionId;
    String uniqueKey;
    boolean cache;

    public static DrawFeedVideoBean parseObject(String jsonString) throws JSONException {
        DrawFeedVideoBean bean = new DrawFeedVideoBean();
        JSONObject jsonObject = new JSONObject(jsonString);
        bean.positionId = jsonObject.optString("positionId");
        bean.width = jsonObject.optInt("width");
        bean.height = jsonObject.optInt("height");
        bean.uniqueKey = jsonObject.optString("uniqueKey");
        bean.cache = jsonObject.optBoolean("cache");

        bean.interruptVideoPlay = jsonObject.optBoolean("interruptVideoPlay");
        bean.pauseIconPath = jsonObject.optString("pauseIconPath");
        bean.pauseIconResource = jsonObject.optInt("pauseIconResource");
        bean.pauseIconSize = jsonObject.optInt("pauseIconSize");
        bean.drawFeedItemLayoutId = jsonObject.optInt("drawFeedItemLayoutId");
        bean.drawFeedPageLayoutId = jsonObject.optInt("drawFeedPageLayoutId");
        bean.gravity = jsonObject.optInt("gravity");
        bean.topMargin = jsonObject.optInt("topMargin");
        bean.bottomMargin = jsonObject.optInt("bottomMargin");
        bean.leftMargin = jsonObject.optInt("leftMargin");
        bean.rightMargin = jsonObject.optInt("rightMargin");
        return bean;
    }


    public boolean isInterruptVideoPlay() {
        return interruptVideoPlay;
    }

    public void setInterruptVideoPlay(boolean interruptVideoPlay) {
        this.interruptVideoPlay = interruptVideoPlay;
    }

    public String getPauseIconPath() {
        return pauseIconPath;
    }

    public void setPauseIconPath(String pauseIconPath) {
        this.pauseIconPath = pauseIconPath;
    }

    public int getPauseIconResource() {
        return pauseIconResource;
    }

    public void setPauseIconResource(int pauseIconResource) {
        this.pauseIconResource = pauseIconResource;
    }

    public int getDrawFeedItemLayoutId() {
        return drawFeedItemLayoutId;
    }

    public void setDrawFeedItemLayoutId(int drawFeedItemLayoutId) {
        this.drawFeedItemLayoutId = drawFeedItemLayoutId;
    }

    public int getDrawFeedPageLayoutId() {
        return drawFeedPageLayoutId;
    }

    public void setDrawFeedPageLayoutId(int drawFeedPageLayoutId) {
        this.drawFeedPageLayoutId = drawFeedPageLayoutId;
    }

    public int getGravity() {
        return gravity;
    }

    public void setGravity(int gravity) {
        this.gravity = gravity;
    }

    public int getTopMargin() {
        return topMargin;
    }

    public void setTopMargin(int topMargin) {
        this.topMargin = topMargin;
    }

    public int getBottomMargin() {
        return bottomMargin;
    }

    public void setBottomMargin(int bottomMargin) {
        this.bottomMargin = bottomMargin;
    }

    public int getLeftMargin() {
        return leftMargin;
    }

    public void setLeftMargin(int leftMargin) {
        this.leftMargin = leftMargin;
    }

    public int getRightMargin() {
        return rightMargin;
    }

    public void setRightMargin(int rightMargin) {
        this.rightMargin = rightMargin;
    }

    public int getPauseIconSize() {
        return pauseIconSize;
    }

    public void setPauseIconSize(int pauseIconSize) {
        this.pauseIconSize = pauseIconSize;
    }

    public int getWidth() {
        return width;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getHeight() {
        return height;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getUniqueKey() {
        return uniqueKey;
    }

    public void setUniqueKey(String uniqueKey) {
        this.uniqueKey = uniqueKey;
    }

    public boolean isCache() {
        return cache;
    }

    public void setCache(boolean cache) {
        this.cache = cache;
    }
}
